import pygame
from enum import Enum, auto
from typing import List, Tuple, Callable

class MenuItem:
    def __init__(self, text: str, action: Callable, position: Tuple[int, int] = (0, 0)):
        self.text = text
        self.action = action
        self.position = position
        self.is_selected = False
        self.color = (255, 255, 255)  # Default white
        self.selected_color = (0, 255, 0)  # Green when selected
        self.font = pygame.font.Font(None, 64)

    def draw(self, screen: pygame.Surface):
        """Draw the menu item"""
        color = self.selected_color if self.is_selected else self.color
        text_surface = self.font.render(self.text, True, color)
        text_rect = text_surface.get_rect(center=self.position)
        screen.blit(text_surface, text_rect)

class GameMode(Enum):
    PLAYER = auto()
    AI_EASY = auto()
    AI_MEDIUM = auto()
    AI_HARD = auto()

class Menu:
    def __init__(self, screen_width: int, screen_height: int):
        self.width = screen_width
        self.height = screen_height
        self.selected_index = 0
        self.items: List[MenuItem] = []
        self.setup_menu_items()

    def setup_menu_items(self):
        """Initialize menu items with their positions"""
        # Calculate vertical spacing
        start_y = self.height // 3
        spacing = 80
        center_x = self.width // 2

        # Create menu items
        items_data = [
            ("Player Game", lambda: GameMode.PLAYER),
            ("AI Easy", lambda: GameMode.AI_EASY),
            ("AI Medium", lambda: GameMode.AI_MEDIUM),
            ("AI Hard", lambda: GameMode.AI_HARD),
            ("Quit", lambda: None)
        ]

        for i, (text, action) in enumerate(items_data):
            position = (center_x, start_y + i * spacing)
            self.items.append(MenuItem(text, action, position))
        
        # Select first item
        self.items[0].is_selected = True

    def handle_input(self, event: pygame.event.Event) -> GameMode:
        """Handle menu navigation and selection"""
        if event.type == pygame.KEYDOWN:
            if event.key == pygame.K_UP:
                # Move selection up
                self.items[self.selected_index].is_selected = False
                self.selected_index = (self.selected_index - 1) % len(self.items)
                self.items[self.selected_index].is_selected = True
            elif event.key == pygame.K_DOWN:
                # Move selection down
                self.items[self.selected_index].is_selected = False
                self.selected_index = (self.selected_index + 1) % len(self.items)
                self.items[self.selected_index].is_selected = True
            elif event.key == pygame.K_RETURN:
                # Execute selected item's action
                return self.items[self.selected_index].action()
        return None

    def draw(self, screen: pygame.Surface):
        """Draw the menu"""
        # Draw title
        title_font = pygame.font.Font(None, 100)
        title_text = title_font.render("AI Snake Game", True, (0, 255, 0))
        title_rect = title_text.get_rect(center=(self.width // 2, 100))
        screen.blit(title_text, title_rect)

        # Draw menu items
        for item in self.items:
            item.draw(screen)

        # Draw instructions
        instruction_font = pygame.font.Font(None, 36)
        instructions = [
            "Use UP/DOWN arrows to navigate",
            "Press ENTER to select",
            "Press ESC to quit"
        ]
        
        start_y = self.height - 150
        for i, instruction in enumerate(instructions):
            text = instruction_font.render(instruction, True, (128, 128, 128))
            rect = text.get_rect(center=(self.width // 2, start_y + i * 30))
            screen.blit(text, rect) 